﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Windows.Forms.Grid.Grouping;
using Syncfusion.Grouping;
using Syncfusion.Windows.Forms.Grid;


namespace DataGrid
{
    public partial class Form1 : Form
    {
        DataSet dataSet;
        public Form1()
        {
            InitializeComponent();
            dataSet = new DataSet();

            #region Initial DataSource
            this.CreateTable();
            this.gridGroupingControl1.DataSource = this.GGC1Table;
            #endregion

            #region Cutomization
            this.gridGroupingControl1.TopLevelGroupOptions.ShowAddNewRecordBeforeDetails = false;
            #endregion
        }

        #region Properties
        //These properties are used to maintain the DataSource
        private DataTable _GGC1Table;
        public DataTable GGC1Table
        {
            get { return _GGC1Table; }
            set { _GGC1Table = value; }
        }

        private DataTable _GGC2Table;
        public DataTable GGC2Table
        {
            get { return _GGC2Table; }
            set { _GGC2Table = value; }
        }
        #endregion

        #region Initial DataSource
        /// <summary>
        /// Default datasource
        /// </summary>
        void CreateTable()
        {
            ReadXml(dataSet, @"GDBDdata.XML");
            this.gridGroupingControl1.DataSource = dataSet.Tables["Products"];
            this.GGC1Table = dataSet.Tables["Products"]; ;
        }
        #endregion

        void ReadXml(DataSet ds, string xmlFileName)
        {
            for (int n = 0; n < 10; n++)
            {
                if (System.IO.File.Exists(xmlFileName))
                {
                    ds.ReadXml(xmlFileName);
                    break;
                }
                xmlFileName = @"..\" + xmlFileName;
            }
        }

        #region Transpose DataSource
        /// <summary>
        /// Used to tranpose the grid datasource
        /// </summary>
        void CreateTable2()
        {
            //Creating the Temporary DataTable
            DataTable _GdcTable = new DataTable();

            //Creating the columns 
            for (int i = 0; i < this.GGC1Table.Rows.Count; i++)
            {
                _GdcTable.Columns.Add("Sample" + i);
            }           

            //Generating the data for transposed grid.
            foreach (GridColumnDescriptor column in this.gridGroupingControl1.TableDescriptor.Columns)
            {
                DataRow dr = _GdcTable.NewRow();
                foreach (Record record in this.gridGroupingControl1.Table.Records)
                {
                    dr[this.gridGroupingControl1.Table.Records.IndexOf(record)] = record.GetValue(column.Name).ToString();
                }
                _GdcTable.Rows.Add(dr);
            } 
           
            //Assigning the datasource
            this._GGC2Table = _GdcTable;
        }
        #endregion

        private void transposeBtn_Click(object sender, EventArgs e)
        {
            this.gridGroupingControl1.ShowColumnHeaders = false;

            //To set the RowHeader cellvalues as column names
            this.gridGroupingControl1.QueryCellStyleInfo += new GridTableCellStyleInfoEventHandler(gridGroupingControl1_QueryCellStyleInfo);

            //Generating the DataSource (Transposing the DataSource)
            this.CreateTable2();

            //Assigning the Transposed datasource
            this.gridGroupingControl1.DataSource = this._GGC2Table;

            this.gridGroupingControl1.Table.DefaultRowHeaderWidth = 120;

        }

        void gridGroupingControl1_QueryCellStyleInfo(object sender, GridTableCellStyleInfoEventArgs e)
        {

            if (e.TableCellIdentity == null)
                return;

            if (e.TableCellIdentity.TableCellType == GridTableCellType.AlternateRecordRowHeaderCell || e.TableCellIdentity .TableCellType == GridTableCellType.RecordRowHeaderCell)
            {
                e.Style.CellType = "Header";
                e.Style.CellValue = this.GGC1Table.Columns[e.TableCellIdentity.RowIndex - 2].ColumnName;
                e.Style.Font.Bold = true;
            }
        }
    }
}
